@@ -1,5 +1,5 @@
 
-#' copy labels from one variable to another
+#' copy meta information from one variable to another
 #' @returns Returns 'to' with ilabelled attributes copied from 'from'
 #' @param to vector
 #' @param from vector
@@ -8,10 +8,15 @@
 i_copy <- function(to, from, what = "all", ...){
   stopifnot(is.atomic(to) || is.atomic(from))
   what <- tolower(what)
+
   label <- attr(to, "labels", TRUE)
   labels <- attr(to, "labels", TRUE)
   na_values <- attr(to, "na_values", TRUE)
   na_range <- attr(to, "na_range", TRUE)
+  scale <- attr(to, "scale", TRUE)
+  annotation <- attr(to, "annotation", TRUE)
+  wording <- attr(to, "wording", TRUE)
+  subject <- attr(to, "subject", TRUE)
 
   if(any(c("all", "label") %in% what)){
     label <- attr(from, "label", TRUE)
@@ -25,6 +30,18 @@ i_copy <- function(to, from, what = "all", ...){
   if(any(c("all", "na_range") %in% what)){
     na_range <- attr(from, "na_range", TRUE)
   }
+  if(any(c("all", "scale") %in% what)){
+    scale <- attr(from, "scale", TRUE)
+  }
+  if(any(c("all", "annotation") %in% what)){
+    annotation <- attr(from, "annotation", TRUE)
+  }
+  if(any(c("all", "wording") %in% what)){
+    wording <- attr(from, "wording", TRUE)
+  }
+  if(any(c("all", "subject") %in% what)){
+    subject <- attr(from, "subject", TRUE)
+  }
 
   structure(
     to,
@@ -32,6 +49,10 @@ i_copy <- function(to, from, what = "all", ...){
     labels = labels,
     na_values = na_values,
     na_range = na_range,
+    scale = scale,
+    annotation = annotation,
+    wording = wording,
+    subject = subject,
     ...
   )
 }
